UPDATE `engine4_core_menuitems` SET `params` = '{"route":"default", "module":"invite", "controller":"index", "action":"index", "icon":"fi fi-rr-mail-plus-circle"}' WHERE `engine4_core_menuitems`.`name` = 'user_settings_invites';